"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateResources = void 0;
const gen2Memory = ['16384MB', '32768MB'];
const minimumCPU = {
    '128MB': 0.083,
    '256MB': 0.167,
    '512MB': 0.333,
    '1024MB': 0.583,
    '2048MB': 1,
    '4096MB': 2,
    '8192MB': 2,
    '16384MB': 4,
    '32768MB': 8
};
const docsLink = 'https://cloud.google.com/functions/docs/configuring/memory';
const validateResources = ({ cpu, memory, gen }) => {
    if (gen2Memory.includes(memory) && gen === 1) {
        throw new Error(`Setting memory to "${memory}" is not supported when gen is 2.

       See ${docsLink} for more information.
      `);
    }
    if (cpu < minimumCPU[memory]) {
        throw new Error(`CPU value of ${cpu} is not enough for memory of ${memory}.
      
       See ${docsLink} for more information
      `);
    }
};
exports.validateResources = validateResources;
//# sourceMappingURL=validate-resources.js.map